<?php

/**
 * This file is part of contao-community-alliance/dependency-container.
 *
 * (c) 2013 Contao Community Alliance
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 *
 * This project is provided in good faith and hope to be usable by anyone.
 *
 * @package    contao-community-alliance/dependency-container
 * @author     Christian Schiffler <c.schiffler@cyberspectrum.de>
 * @author     Tristan Lins <tristan.lins@bit3.de>
 * @copyright  2013-2015 Contao Community Alliance
 * @license    https://github.com/contao-community-alliance/dependency-container/blob/master/LICENSE LGPL-3.0+
 * @link       http://c-c-a.org
 * @filesource
 */

namespace DependencyInjection\Container\DependencyInjection;

use Contao\CoreBundle\Framework\ContaoFramework;

/**
 * Class PimpleProvider
 *
 * @package DependencyInjection\Container\DependencyInjection
 */
class LegacyContainerProvider
{
    /**
     * The contao framework.
     *
     * @var ContaoFramework
     */
    private $framework;

    /**
     * ContainerInitializer constructor.
     *
     * @param ContaoFramework $framework
     */
    public function __construct(ContaoFramework $framework = null)
    {
        $this->framework = $framework;
    }

    /**
     * Get the legacy container.
     *
     * @return \Pimple
     *
     * @SuppressWarnings(PHPMD.Superglobals)
     */
    public function getContainer()
    {
        // First initialize Contao framework. Container should be built here.
        $this->framework->initialize();

        $container = $GLOBALS['container'];

        if (!$container instanceof \Pimple) {
            throw new \RuntimeException(
                'Dependency container is incompatible class. Expected \Pimple but found ' .
                get_class($container),
                1
            );
        }

        return $container;
    }
}
